@@ -11,6 +11,7 @@ class GmapsSelectAutocomplete(forms.TextInput):
 
     def render(self, name, value, attrs=None):
         res = super(GmapsSelectAutocomplete, self).render(name, value, attrs)
+        print "\n\nVALUE: ", value
         tmp_id = attrs['id'].replace(self.plugin_options['gmaps_field_name'], '')
 
         if 'geocode_field' in self.plugin_options:
@@ -46,12 +47,20 @@ class GmapsSelectAutocomplete(forms.TextInput):
         js = (
             'https://maps.googleapis.com/maps/api/js?v=3.14&key={}&sensor=false'.format(settings.GMAPS_API_KEY),
             settings.JQUERY_LIB,
-            u'{}gmaps/{}/select2.min.js'.format(settings.STATIC_URL, settings.SELECT2_VERSION),
+            settings.SELECT2_LIB,
             u'{}gmaps/js/gmap.js'.format(settings.STATIC_URL),
             u'{}gmaps/js/gmaps__init.js'.format(settings.STATIC_URL),
         )
         css = {u"all": (
-            u"{}gmaps/{}/select2.css".format(settings.STATIC_URL, settings.SELECT2_VERSION),
+            settings.SELECT2_CSS_LIB,
             u"{}gmaps/css/gmaps.css".format(settings.STATIC_URL),
         )}
 
+
+class GeotypeSelect(forms.Select):
+
+    def render(self, name, value, attrs=None, choices=()):
+        if value:
+            choices = list(choices)
+            choices.append((value, value))
+        return super(GeotypeSelect, self).render(name, value, attrs, choices)
